==> cscec5b-fbxt-api-3.0.1-20221010.101154-85-sources.jar: com/ejianc/business/fbxt/odd/vo/OddSetVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包协同设置实体
 * 
 * @author generator
 * 
 */
public class OddSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long orgParentId; // 上级组织主键
    private Boolean setState; // 是否设置，0-未设置，1-已设置
    private Boolean suppStatus; // 是否启用供方协同，0-未启用，1-已启用
    private Boolean confirmStatus; // 是否供方确认，0-不需确认，1-需确认
    private Boolean forceApply;    // 是否强制申请单，0-不强制，1-强制

    private List<ReceiveVO> receiveLists = new ArrayList<>(); // 接收人

    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织主键
     */
    public Long getOrgParentId() {
        return orgParentId;
    }

    /**
     * 上级组织主键
     */
    public void setOrgParentId(Long orgParentId) {
        this.orgParentId = orgParentId;
    }
    /**
     * 是否设置，0-未设置，1-已设置
     */
    public Boolean getSetState() {
        return setState;
    }

    /**
     * 是否设置，0-未设置，1-已设置
     */
    public void setSetState(Boolean setState) {
        this.setState = setState;
    }
    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public Boolean getSuppStatus() {
        return suppStatus;
    }

    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public void setSuppStatus(Boolean suppStatus) {
        this.suppStatus = suppStatus;
    }
    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public Boolean getConfirmStatus() {
        return confirmStatus;
    }

    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public void setConfirmStatus(Boolean confirmStatus) {
        this.confirmStatus = confirmStatus;
    }

    public Boolean getForceApply() {
        return forceApply;
    }

    public void setForceApply(Boolean forceApply) {
        this.forceApply = forceApply;
    }

    public List<ReceiveVO> getReceiveLists() {
        return receiveLists;
    }

    public void setReceiveLists(List<ReceiveVO> receiveLists) {
        this.receiveLists = receiveLists;
    }
}

==> cscec5b-fbxt-api-3.0.1-20240306.013724-187-sources.jar: com/ejianc/business/fbxt/odd/vo/OddSetVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包协同设置实体
 *
 * @author generator
 *
 */
public class OddSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long orgParentId; // 上级组织主键
    private Boolean setState; // 是否设置，0-未设置，1-已设置
    private Boolean suppStatus; // 是否启用供方协同，0-未启用，1-已启用
    private Boolean confirmStatus; // 是否供方确认，0-不需确认，1-需确认
    private Boolean forceApply;    // 是否强制申请单，0-不强制，1-强制
    private Boolean suppAssbookExcess; // 是否允许供应商超量发起施工任务书，0-未启用，1-已启用
    private Boolean suppOddAdd; // 是否允许供应商自制发起用工单，0-未启用，1-已启用

    private List<ReceiveVO> receiveLists = new ArrayList<>(); // 接收人

    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织主键
     */
    public Long getOrgParentId() {
        return orgParentId;
    }

    /**
     * 上级组织主键
     */
    public void setOrgParentId(Long orgParentId) {
        this.orgParentId = orgParentId;
    }
    /**
     * 是否设置，0-未设置，1-已设置
     */
    public Boolean getSetState() {
        return setState;
    }

    /**
     * 是否设置，0-未设置，1-已设置
     */
    public void setSetState(Boolean setState) {
        this.setState = setState;
    }
    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public Boolean getSuppStatus() {
        return suppStatus;
    }

    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public void setSuppStatus(Boolean suppStatus) {
        this.suppStatus = suppStatus;
    }
    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public Boolean getConfirmStatus() {
        return confirmStatus;
    }

    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public void setConfirmStatus(Boolean confirmStatus) {
        this.confirmStatus = confirmStatus;
    }

    public Boolean getForceApply() {
        return forceApply;
    }

    public void setForceApply(Boolean forceApply) {
        this.forceApply = forceApply;
    }

    public Boolean getSuppAssbookExcess() {
        return suppAssbookExcess;
    }

    public void setSuppAssbookExcess(Boolean suppAssbookExcess) {
        this.suppAssbookExcess = suppAssbookExcess;
    }

    public Boolean getSuppOddAdd() {
        return suppOddAdd;
    }

    public void setSuppOddAdd(Boolean suppOddAdd) {
        this.suppOddAdd = suppOddAdd;
    }

    public List<ReceiveVO> getReceiveLists() {
        return receiveLists;
    }

    public void setReceiveLists(List<ReceiveVO> receiveLists) {
        this.receiveLists = receiveLists;
    }
}
